Stan Math Library: stan/math/prim/scal/fun/binomial_coefficient_log.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
binomial_coefficient_log.hpp File Reference
`#include <boost/math/special_functions/gamma.hpp>`
`#include <boost/math/tools/promotion.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T_N , typename T_n >
boost::math::tools::promote_args< T_N, T_n >::type | stan::math::binomial_coefficient_log (const T_N N, const T_n n)
| Return the log of the binomial coefficient for the specified arguments. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.